// src/logger.ts
var levels = {
  verbose: 0,
  info: 1,
  warn: 2,
  error: 3
};
var Logger = class {
  namespace;
  level;
  enabled;
  constructor(namespace, options = {}) {
    this.namespace = namespace;
    this.level = options.level || "info";
    this.enabled = options.enabled ?? true;
  }
  shouldLog(msgLevel) {
    return this.enabled && levels[msgLevel] >= levels[this.level];
  }
  verbose(...args) {
    if (this.shouldLog("verbose")) {
      console.log(`[${this.namespace}]`, ...args);
    }
  }
  info(...args) {
    if (this.shouldLog("info")) {
      console.info(`[${this.namespace}]`, ...args);
    }
  }
  warn(...args) {
    if (this.shouldLog("warn")) {
      console.warn(`[${this.namespace}]`, ...args);
    }
  }
  error(...args) {
    if (this.shouldLog("error")) {
      console.error(`[${this.namespace}]`, ...args);
    }
  }
};
function createLogger(namespace, options) {
  return new Logger(namespace, options);
}

export { Logger, createLogger };
